# aeza

Этот пакет создан, для того чтобы занять название aeza в pypi.org. Он принадлежит проекту [aeza.net](https://aeza.net/).

This package is created to occupy the name aeza in pypi.org. It belongs to the [aeza.net](https://aeza.net/) project
